==> lmomco_0.86.tar.gz: lmomco/man/pargam.Rd <==
\name{pargam}
\alias{pargam}
\title{Estimate the Parameters of the Gamma Distribution}
\description{
This function estimates the parameters of the Gamma distribution given
the L-moments of the data in an L-moment object such as that returned by
\code{lmom.ub}. The relation between distribution parameters and L-moments
is seen under \code{lmomgam}. The parameters can not be estimated if \eqn{\lambda_1 \le \lambda_2} or \eqn{\lambda_2 \le 0}.
}
\usage{
pargam(lmom)
}
\arguments{
  \item{lmom}{A L-moment object created by \code{\link{lmom.ub}}
or \code{\link{pwm2lmom}}.}
}

\value{
  An R \code{list} is returned.

  \item{type}{The type of distribution: \code{gam}.}
  \item{para}{The parameters of the distribution.}
  \item{source}{The source of the parameters: \dQuote{pargam}.}
}
\references{
Hosking, J.R.M., 1990, L-moments---Analysis and estimation of
distributions using linear combinations of order statistics: Journal
of the Royal Statistical Society, Series B, vol. 52, p. 105--124.

Hosking, J.R.M., 1996, FORTRAN routines for use with the method of L-moments:
Version 3, IBM Research Report RC20525, T.J. Watson Research Center,
Yorktown Heights, New York.

Hosking, J.R.M. and Wallis, J.R., 1997, Regional frequency analysis---An
approach based on L-moments: Cambridge University Press.
}
\author{ W.H. Asquith}
\seealso{\code{\link{lmom.ub}}, \code{\link{lmomgam}},
\code{\link{cdfgam}}, \code{\link{quagam}}
}
\examples{
lmr <- lmom.ub(rnorm(20))
pargam(lmr)
}
\keyword{distribution}

==> lmomco_1.7.2.tar.gz: lmomco/man/pargam.Rd <==
\name{pargam}
\alias{pargam}
\title{Estimate the Parameters of the Gamma Distribution}
\description{
This function estimates the parameters of the Gamma distribution given
the L-moments of the data in an L-moment object such as that returned by
\code{lmom.ub}. The relation between distribution parameters and L-moments
is seen under \code{lmomgam}. The parameters can not be estimated if \eqn{\lambda_1 \le \lambda_2} or \eqn{\lambda_2 \le 0}.
}
\usage{
pargam(lmom,checklmom=TRUE)
}
\arguments{
  \item{lmom}{A L-moment object created by \code{\link{lmom.ub}}
or \code{\link{pwm2lmom}}.}
  \item{checklmom}{Should the \code{lmom} be checked for validity using the \code{are.lmom.valid} function. Normally this should be left as the default and it is very unlikely that the L-moments will not be viable (particularly in the \eqn{\tau_4} and \eqn{\tau_3} inequality). However, for some circumstances or large simulation exercises then one might want to bypass this check.}
}

\value{
  An R \code{list} is returned.

  \item{type}{The type of distribution: \code{gam}.}
  \item{para}{The parameters of the distribution.}
  \item{source}{The source of the parameters: \dQuote{pargam}.}
}
\references{
Hosking, J.R.M., 1990, L-moments---Analysis and estimation of
distributions using linear combinations of order statistics: Journal
of the Royal Statistical Society, Series B, vol. 52, p. 105--124.

Hosking, J.R.M., 1996, FORTRAN routines for use with the method of L-moments:
Version 3, IBM Research Report RC20525, T.J. Watson Research Center,
Yorktown Heights, New York.

Hosking, J.R.M. and Wallis, J.R., 1997, Regional frequency analysis---An
approach based on L-moments: Cambridge University Press.
}
\author{ W.H. Asquith}
\seealso{\code{\link{lmom.ub}}, \code{\link{lmomgam}},
\code{\link{cdfgam}}, \code{\link{quagam}}
}
\examples{
lmr <- lmom.ub(rnorm(20))
pargam(lmr)
}
\keyword{distribution}
